Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FieldSet ¶
type FieldSet map[string]struct{}
FieldSet is a set of strings representing fields.
func (FieldSet) Difference ¶
Difference returns the fields in s that are not in other.
func (FieldSet) Intersection ¶
Intersection returns the fields that are in both s and other.
func (FieldSet) IsSubsetOf ¶
IsSubsetOf returns true if s is a subset of other.
type FlattenedSchemaRaw ¶
type ResourceConfigDiff ¶
type ResourceDiff ¶
type ResourceDiff struct {
ResourceConfig ResourceConfigDiff
FlattenedSchema FlattenedSchemaRaw
Fields map[string]FieldDiff
FieldSets ResourceFieldSetsDiff
}
func (ResourceDiff) IsFieldInNewNestedStructure ¶
func (rd ResourceDiff) IsFieldInNewNestedStructure(fieldPath string) bool
IsFieldInNewNestedStructure determines if a field is part of a completely new nested structure
func (ResourceDiff) IsNewResource ¶
func (rd ResourceDiff) IsNewResource() bool
type ResourceDiffInterface ¶
type ResourceFieldSets ¶
type ResourceFieldSetsDiff ¶
type ResourceFieldSetsDiff struct {
Old ResourceFieldSets
New ResourceFieldSets
}
type SchemaDiff ¶
type SchemaDiff map[string]ResourceDiff
SchemaDiff is a nested map with resource names as top-level keys.
func ComputeSchemaDiff ¶
func ComputeSchemaDiff(oldResourceMap, newResourceMap map[string]*schema.Resource) SchemaDiff
Click to show internal directories.
Click to hide internal directories.